MiniWorldMaker
==============

MiniWorldMaker is a game-engine written in python and pygame designed for education to create 2D mini worlds and games.

![Miniworldmaker](/_images/miniworldmaker.png)

Features
--------

  * **Objects First** programming: Object oriented programming without classes.

  * **Tiles and Pixel-Games**: For different types of games.

  * **Integrated physics engine**: For physics based games, based on **pymunk**

  * Integrated Manager for GUI Elements, Music and Sound effects

  * **Open Source**

  * See: [Codeberg](https://codeberg.org/a_siebel/miniworldmaker) | [Documentation](http://miniworldmaker.de/) | [PyPi](https://pypi.org/project/miniworldmaker/)

Credits
---------

  * [Greenfoot](https://www.greenfoot.org/door): The model for this framework.

  * [Deepl](https://www.deepl.com/translator): Assistant for translating pages.
  
  * [Kenny Assets](https://www.kenney.nl/assets): Most of the images in the example-code are based on kenny assets. 